export declare class List<T> {
    private init;
    /**
     * The array value
     */
    value: T[];
    static cast: <T_1>(value: T_1 | T_1[] | null | undefined) => T_1[];
    /**
     * Cast a value to an array
     */
    static from<T>(value: T | T[] | null): List<T>;
    /**
     * Creates the array from specified length
     */
    static fromLength<T>(length: number, cb: (index: number) => T): List<T>;
    /**
     * Creates an array instance from array literal
     */
    constructor(init?: T[]);
    /**
     * Creates a copy of the array
     */
    clone: () => List<T>;
    /**
     * The length of the array
     */
    get size(): number;
    /**
     * The first item in the array
     */
    get first(): T | undefined;
    /**
     *  The last item in the array
     */
    get last(): T | undefined;
    /**
     * Returns whether the array is empty
     */
    get isEmpty(): boolean;
    /**
     * Returns whether the array contains a value
     */
    has: (value: T) => boolean;
    /**
     * Resets the array to the initial value
     */
    reset: () => List<T>;
    /**
     * Returns the item at the specified index
     */
    at: (index: number) => T | undefined;
    /**
     * Sets the value of the array
     */
    set: (value: T[]) => List<T>;
    /**
     * Add an item to the end of the array
     */
    add: (...items: T[]) => List<T>;
    /**
     * Removes an item at the specified index
     */
    removeAt: (index: number) => List<T>;
    /**
     * Removes an item from the array
     */
    remove: (item: T) => List<T>;
    /**
     * Execute a callback for each item in the array
     */
    each: <K>(fn: (value: T, index: number, arr: T[]) => K) => void;
    /**
     * Find the first item that matches the predicate
     */
    find: (fn: (value: T, key: number, arr: T[]) => boolean) => T | undefined;
    /**
     * Filter item(s) from the array based on predicate
     */
    filter: (fn: (value: T, key: number, arr: T[]) => boolean) => List<T>;
    /**
     * Returns the array with its values cleared
     */
    clear: () => List<T>;
    /**
     * Inserts an item into array at index position
     */
    insert: (index: number, ...items: T[]) => List<T>;
    /**
     * Returns the array with the new value replaced at the specified index
     */
    replace: (index: number, ...items: T[]) => List<T>;
    /**
     * Returns the array with items moved to a different position
     */
    move: (from: number, to: number) => List<T>;
    /**
     * Returns the index of the first item found
     */
    indexOf: (item: T) => number;
    /**
     * Returns the next index in the array given the current index
     */
    nextIndex: (index: number, step?: number, loop?: boolean) => number;
    /**
     * Returns the next item in the array given the current index
     */
    next: (index: number, step?: number, loop?: boolean) => T | undefined;
    /**
     * Returns the previous index in the array given the current index
     */
    prevIndex: (index: number, step?: number, loop?: boolean) => number;
    /**
     * Returns the previous item in the array given the current index
     */
    prev: (index: number, step?: number, loop?: boolean) => T | undefined;
    /**
     * Returns the first item that matches the query
     */
    search: (query: string | null | undefined, toString: (item: T) => string, current: T | undefined) => T | undefined;
    /**
     * Returns an array with values split into smaller chunks or groups,
     * depending on the specified size
     */
    chunk: (size: number) => List<List<T>>;
    /**
     * Iterator for the underlying array
     */
    [Symbol.iterator](): Generator<T, void, unknown>;
}
